"""Public package API for qpip."""

from .cli import main
from .core import (
    DEFAULT_MIRROR,
    MIRROR_ALIASES,
    MIRRORS,
    build_pip_command,
    format_mirrors,
    get_default_mirror,
    normalize_mirror_name,
    run_pip_with_mirror,
    should_inject_mirror,
)

__all__ = [
    "DEFAULT_MIRROR",
    "MIRROR_ALIASES",
    "MIRRORS",
    "build_pip_command",
    "format_mirrors",
    "get_default_mirror",
    "main",
    "normalize_mirror_name",
    "run_pip_with_mirror",
    "should_inject_mirror",
]

__version__ = "0.1.0"
